#
# spec file for package ark
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           ark
Version:        24.12.2
Release:        1.1
Summary:        KDE Archiver Tool
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/ark
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6FileMetaData) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KF6Pty) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(libarchive) >= 3.3.3
BuildRequires:  pkgconfig(libzip) >= 1.3.0
BuildRequires:  pkgconfig(zlib)
Recommends:     /usr/bin/lzop
Recommends:     7zip
Recommends:     lrzip
Recommends:     lzop
Recommends:     unar
Recommends:     unzip
Recommends:     xz
Recommends:     zstd
Suggests:       arj
Obsoletes:      ark-devel

%description
This is a KDE application to work with compressed archives.

%package -n libkerfuffle24
Summary:        KDE Archiver Tool

%description -n libkerfuffle24
This is a KDE application to work with compressed archives.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-man --with-html --all-name


%ldconfig_scriptlets -n libkerfuffle24

%files
%doc %lang(en) %{_kf6_htmldir}/en/ark/
%doc %{_kf6_mandir}/man1/ark.1%{?ext_man}
%{_kf6_applicationsdir}/org.kde.ark.desktop
%{_kf6_appstreamdir}/org.kde.ark.appdata.xml
%{_kf6_bindir}/ark
%{_kf6_configkcfgdir}/ark.kcfg
%{_kf6_configdir}/arkrc
%{_kf6_sharedir}/kconf_update/ark.upd
%{_kf6_sharedir}/kconf_update/ark_add_hamburgermenu_to_toolbar.sh
%{_kf6_debugdir}/ark.categories
%{_kf6_iconsdir}/hicolor/*/apps/*
%{_kf6_plugindir}/kf6/parts/arkpart.so
%{_kf6_plugindir}/kerfuffle/
%dir %{_kf6_plugindir}/kf6/kfileitemaction
%{_kf6_plugindir}/kf6/kfileitemaction/compressfileitemaction.so
%{_kf6_plugindir}/kf6/kfileitemaction/extractfileitemaction.so
%dir %{_kf6_plugindir}/kf6/kio_dnd
%{_kf6_plugindir}/kf6/kio_dnd/extracthere.so

%files -n libkerfuffle24
%{_kf6_libdir}/libkerfuffle.so.*

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/ark/

%changelog
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Changes since 24.11.90:
  * Treat absolute paths as relative paths during extraction
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Don't include quiet packages in feature_summary
  * Add developer name to appdata
  * fix clang-format
  * Disable "compress to tar.gz/zip" service menu items in read-only dirs
  * Re-enable clang-format CI job
  * Simply combine string for log message
  * Reformat with clang-format and avoid version differences
  * Convert .reuse/dep5 to REUSE.toml
  * Fix clazy-non-pod-global-static warnings
  * Fix clazy-detaching-temporary warnings
  * Fix clazy-use-static-qregularexpression warnings
  * Fix clazy-fully-qualified-moc-types warnings
  * cliinterface: drop unnecessary qRegisterMetaType
  * Fix validation of tar mimetypes
  * PluginManager: add api to retrieve plugin by id
  * Fix display of ampersands in filename (kde#463279)
  * Initialize pointer
  * const'ify pointer + initialize to nullptr
  * Show headers in qtc6
  * Use modern kf6
  * Const'ify pointer
  * Set up KCrash after KAboutData::setApplicationData()
  * Port [=] operator
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * snapcraft: add udisks2 plug
  * snapcraft: Remove plugs now handled by extension/snapd.
  * snapcraft: fix libzip package name.
  * snapcraft: Add theme support, minor fixes.
  * cliinterface: adapt to behavior change in QTemporaryDir (kde#487229)
  * Logging category rename from "ARK" to "ARK_LOG"
  * Explicitly link against Qt::DBus
  * Fix minor typo
  * cli7zplugin: update cmake warning message
  * createdialogtest: fix 7z expected encryption with libarchive
  * extracttest: skip 7z multivolume with libarchive
  * Move 7z multivolume load test to cli7ztest
  * libarchive: add support for unencrypted 7-zip
  * Cleanup bits now in extension.`
  * snapcraft: Initial port to kf6.
- Drop patch, merged upstream:
  * 0001-cliinterface-adapt-to-behavior-change-in-QTemporaryD.patch
* Sat Jul 13 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix tmp folder cleanup (kde#487229):
  * 0001-cliinterface-adapt-to-behavior-change-in-QTemporaryD.patch
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * Tests: Comment out test that fails to pass
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Explicitly link against Qt::DBus
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * clirarplugin: disable RAR4 compression method (kde#483748)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * clirartest: drop addArgs test for RAR4
  * clirarplugin: disable RAR4 compression method (kde#483748)
  * Make clang-format happy
  * Remove documentation that doesn't compile
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Don't rely on qtpaths for kconf_update scripts
  * Specify umask for permission tests
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Specify umask for permission tests
  * cli7zplugin: improve compatibility with original 7-Zip
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Fix opening of AppImage files
  * Fix checks using old ISO mimetype
  * Don't hardcode bzip2 mimetype in tests
  * Fix support for bzip2 format with shared-mime-info 2.3
  * Explicitly support new application/vnd.efi.iso mimetype
  * snapcraft: bump content pack version.
- Drop patch, merged upstream:
  * 0001-Fix-support-for-bzip2-format-with-shared-mime-info-2.patch
* Sat Oct 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix bzip2 support with shared-mime-info >= 2.3:
  * 0001-Fix-support-for-bzip2-format-with-shared-mime-info-2.patch
- Drop patch, not necessary since Leap 15.2:
  * 0001-Support-building-against-libarchive-3.3.2-again.patch
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * snapcraft: put rar in list.
  * snapcraft: rar in amd64 only.
  * snapcraft: set qt plugin path in build and runtime env.
  * snapcraft: Initial add file
  * Drop unused ItemModels dependency
  * Add missing KWindowSystem dependency
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Make sure welcomeview messages are extracted (kde#472341)
  * Port QString::count() which is deprecated in qt6
  * Disable doc build for Qt6 for now
  * Adjust CI to KF6
  * Adapt part metadata handling to KF6
  * Adapt part factory to KF6
  * Remove unused include
  * Convert desktop file metadata to JSON for KF6
  * Allow building against KF6 libs
  * doc: usa a non-deprecated entity in the man page
  * loadtest: add test for a simple static library
  * loadtest: test number of entries
  * lastPathSegment: don't strip slash if it is the only character in the path (kde#469795)
  * Update homepage URL to https://apps.kde.org/ark (kde#469583)
  * Port sidebar to QDockWidget
  * Small code improvements
  * Fix leaking actions
  * Call showWelcomeScreen() only when needed
  * Bump KF_MIN_VERSION to 5.101
  * New welcome screen UI
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * lastPathSegment: don't strip slash if it is the only character in the path (kde#469795)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Mon Dec 12 2022 Dirk Müller <dmueller@suse.com>
- switch to pkgconfig(zlib) so that alternative providers can be
  used
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
- Rebase 0001-Support-building-against-libarchive-3.3.2-again.patch
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
- Drop patches, now upstream:
  * 0001-remove-l-flag-to-7z-a.patch
  * 0001-Support-7zip-as-well-as-p7zip.patch
* Fri May 13 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add patches to fix issues caused by p7zip replacement in
  openSUSE (boo#1199190):
  * 0001-remove-l-flag-to-7z-a.patch
  * 0001-Support-7zip-as-well-as-p7zip.patch
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Fri Apr 22 2022 Wolfgang Bauer <wbauer@tmo.at>
- Fix soversion
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Skip parent directory check if it is already read-only
  * Skip non-local files in extract file item action
  * Cache result of libarchiveHasLzo
  * Use a better and simpler default name for multi-file archives
  * [compress action] Enable fancy "job finished" notification
  * app/compressfileitemaction: Show archive name in menu actions
  * kerfuffle/addtoarchive: Add getFileName()
  * [Previewer] Use file name in archive for window caption
  * Kdelibs4ConfigMigrator will be removed in qt6
  * Do not highlight file after compression (kde#440663)
  * We depend agains 5.86.
  * Kerfuffle CreateJob: delete addJob in dtor (kde#443540)
  * Mark LoadJob as transient
  * Fix extraction "Dolphin Actions" not abiding "Open destination
    folder after extracting" setting. (kde#319134)
  * [libarchiveplugin] Remove trailing slash while there is one
  * [libarchiveplugin] Handle absolute paths
  * Make AddToArchive::fileName() const.
  * Port away from deprecated KPluginLoader
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Fix multivolume archive creation (kde#448065)
  * zip: Fix setting un-initialized access time (kde#450125)
  * Fix build when libzip is missing
  * libzip: Implement proper cancelation, using libzip 1.6
  * CreateJob: Clean up temp file after cancellation
  * libzipplugin: Prevent crash when canceling archive creation (kde#446926)
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Overwrite dialog: Don't pretend source and dest url are the same (kde#436556)
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Hide welcome screen as soon as we know we're loading a file (kde#441529)
  * Do not highlight file after compression (kde#440663)
  * Fix extraction "Dolphin Actions" not abiding "Open destination folder
    after extracting" setting. (kde#319134)
  * Kerfuffle CreateJob: delete addJob in dtor (kde#443540)
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Fix loading some zip files (kde#445533)
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Emit readiness when creating new archive (kde#445610)
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * zip: Fix detection of backslashed zips (kde#444965)
  * Remove duplicate include from .cpp/.h
  * Use KPluginMetaData::findPlugins when we use kf5-5.86
  * Add license information in SPDX format for icons
  * Convert remaining MIT licenses to SPDX
  * Convert missing author statements to SPDX
  * Clean up excess newlines at end of license headers
  * Remove unneeded stements from license headers
  * Remove obsolete COPYING file
  * Convert license headers to SPDX
  * Cleaup AddJob on destruction (kde#442774)
  * Port deprecated method
  * Add FreeBSD CI
  * Remove redundant close button at the bottom of the preview window (kde#434517)
  * Enable Linux CI
  * Add kde-ci.yml
  * fix: Dolphin doesn't fully quit after Compress from context menu (kde#441813)
  * Clean up unneeded JSON parameter in kcoreaddons_add_plugin
  * We depend against C++17 => we can use std::as_const
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Changes since 21.08.2:
  * Cleanup AddJob on destruction (kde#442774)
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * fix: Dolphin doesn't fully quit after Compress from context menu (kde#441813)
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Mon Jul 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Port away from deprecated KConfigDialogManager::changedMap
  * Add support for single files compressed with zstd (kde#434540)
  * Revert addition of "application/zstd" as archive format
  * libzipplugin: revert zip_source_file from using unique_ptr
  * libzipplugin: some changes for merge review.
  * libzipplugin: hack for zstd max compression method.
  * libzipplugin: fix for pre 1.8.0 libzip versions.
  * libzipplugin: support lzma xz for libzip 1.8.0+
  * libzipplugin: replace almost all raw pointers with unique_ptr
  * clirartest: Set the locale to english
  * Bring back KPtyProcess include
  * Remove unused includes
  * Remove check about qt version
  * As we depend against qt5.15 we can use qt macro/Qt::
  * It's already defined in KDEFrameworkCompilerSettings
  * Time to increase version
  * Adding "application/zstd" mimetype
  * Update Flatpak to 5.15 runtime
  * Remove qt prefix
  * Clean up ServiceType property usage in JSON based plugins
  * FileItemActions: Make plugins more intuitive and interactive
  * Show a "Welcome screen" when launched without an archive
  * Set a better default window size
  * Remove .travis.yml
  * Remove forward declaration when we already include file
  * Simplify part loading code
  * Repair ark startup: make it find its own part again
  * Add missing KConfig linkage
  * Install the part in kf5/parts/
  * Port to KRecentFilesMenu
  * Refactor preview handling
  * appstream: fix homepage url
  * Support for zip files using backslashes as the path separator.
  * Use QStringTokenizer for string splitting
  * Require C++17
  * Simplify fast path in ArchiveModel::parentFor
  * Avoid QString (de)allocations in Entry::find
  * Avoid another unnecessary string split
  * Avoid using QString::split
  * Use imported targets for libzip and zlib
- Only install the license files once
- Remove the unrar 'Suggests'.
* Tue Jul 20 2021 Yaroslav Kurlaev <yaroslav.kurlaev@gmail.com>
- Recommend unar
  * it can handle RAR archives without non-free code
  * as well as LHA archives
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Remove the width/height from screenshot
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Thu Jun  3 2021 Christian Trippe <ctrippe@opensuse.org>
- Always recommend p7zip-full as this is present from Leap 15.2 onwoards
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- Changes since 21.03.80:
  * appstream: fix homepage url
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes since 20.12.3, only listing bugfixes:
  * Add destUrl to jobs (kde#408778)
  * Display confirmation dialog only once when files in archive are modified (kde#382606)
  * Ark KPart: restore mismatch of componentname and plugin id (kde#429616)
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- Changes since 20.12.1:
  * Show 'Compress' menu on multiple selected archives of the same type (kde#430086)
  * Fix crash after closing the window while loading a TAR archive (kde#410092)
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes since 20.08.3, only listing bugfixes:
  * Fix extraction to directories with unicode names when using the Extract file menu (kde#408186)
  * Override text of saveAs standard action (kde#426960)
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- No code change since 20.08.2
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Changes since 20.08.0:
  * Pass the ARCHIVE_EXTRACT_SECURE_SYMLINKS flag to libarchive
  * appdata: use canonical help URL
- Dropped patches, now upstream:
  * 0001-Pass-the-ARCHIVE_EXTRACT_SECURE_SYMLINKS-flag-to-lib.patch
* Thu Aug 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to prevent path traversal (boo#1175857, CVE-2020-24654):
  * 0001-Pass-the-ARCHIVE_EXTRACT_SECURE_SYMLINKS-flag-to-lib.patch
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Tue Aug  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * Fix vulnerability to path traversal attacks
- Drop 0001-Fix-vulnerability-to-path-traversal-attacks.patch,
  Merged upstream
* Mon Aug  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to prevent directory traversal (boo#1174773, CVE-2020-16116)
  * 0001-Fix-vulnerability-to-path-traversal-attacks.patch
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Changes since 20.04.3:
  * Minor fixes for Flathub submission
  * Port to KIO::ApplicationLauncherJob
  * clirar: Remove unnecessary QRegularExpression in readExtractLine()
  * Optimize LoadJob::onNewEntry
  * libarchive backend: display permissions in octal format
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- No code change since 20.04.2
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * libarchive: Improve error-handling when loading archive
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Forward errors from archive interface when batch-extracting
  * libzip: Enable progress when batch-extracting
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes to list here.
- Add patch to allow building with libarchive 3.3.2:
  * 0001-Support-building-against-libarchive-3.3.2-again.patch
- Dropped patches for obsolete distribution versions:
  * lower-libarchive-minimum-version.patch
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * Drop ark.cliexample debug category
  * Update HACKING file
  * Translate MIME type description
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes to list here.
- Remove outdated minimum versions in spec
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * Prevent drops from non-local URLs (kde#409835)
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * fall back to nummerical owner and group if no text representation exists
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * Fix build with cmake < 3.7
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Add missing include
  * Remove unused includes
  * Fix ECM version comparison
  * Install in new logging directory when we use kf5 5.59.0
  * Fix forward declaration
  * ReadWriteLibarchivePlugin: always return false if jobs are killed
  * Part: reset UI after aborting creation of new archives
  * ReadWriteLibarchivePlugin: call archive_write_fail on fail
  * Simplify kill logic
  * Part: call updateWithDefaults() instead of setting an invalid index
  * ReadWriteLibarchivePlugin: stop calling QSaveFile::commit() on fail
  * ReadWriteLibarchivePlugin: bring back an old TODO
  * Promote m_operationMode as protected member of ReadWriteArchiveInterface
  * CMake: use proper construct to compare versions
  * Make it compile without foreach
  * clirar: Use switch-case instead of if-else
  * ReadWriteLibarchivePlugin: simplify error check
  * ReadWriteLibarchivePlugin: move declaration near to usage
  * ReadWriteLibarchivePlugin: rename variable
  * ReadWriteLibarchivePlugin: remove stale comment
  * BatchExtract: improve error reporting when a job fails
* Thu Jul 18 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use kf5_debugdir macro for specifying the logging categories location
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Do not use Q_DECLARE_METATYPE(KPluginMetaData) with KF 5.60+
  * Fix version number
  * CreateJob: connect to progress() signal instead of KJob::percent() (kde#402824)
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Get columns to show from first file entry (kde#406135)
  * Stop crashing when invoking batch mode without urls
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * AddToArchive: fix filename preset for folders (kde#406812)
  * Fix ark cannot be added as favourite in GNOME
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * Handle locked RAR archives (kde#368851)
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * clirar: Remove double backslashes in isPasswordPrompt()
  * Fix progress info for CreateJob (kde#382599)
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
- Refreshed patches:
  * lower-libarchive-minimum-version.patch
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * Fix loading of tar.zst archives (kde#404464)
  * cli7ztest: add failing test case for zip folders with RDA attributes
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Remember part URL to delete the tempfile even if the user used save as. (kde#402529)
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Use more https in links
- Refreshed patches:
  * lower-libarchive-minimum-version.patch
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Add donation url to appdata
  * clizip: Insert break statement
  * Bump minimum Qt version to 5.8
  * Get rid of gcc warnings
  * Fix zstd autotest on Jenkins
  * Remove extra semicolon
  * Add caption to the screenshot
  * Add a missing end parenthesis
  * Update copyright year
  * Add support for Zstd-compressed Tar-archives
  * libzipplugin: Simplify registration of progress callbacks
  * Introduce default value for OperationMode enum
  * Use Ark part only when mime type exactly matches a supported type (kde#398531)
  * Use KDEFrameworkCompilerSettings
  * Silence up false positive EBN check and fix some typos
  * Use lambdas instead of QSignalMapper
  * [CompressFileItemAction] Don't offer for non-local URLs
  * Add new option (-m) to man page
  * Add --mimetypes command line option
- Refreshed patches:
  * lower-libarchive-minimum-version.patch
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Disable Compress menu on remote URLs
  * Show 'Extract' menu on archives without extension (kde#399806)
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Downgrade warning to debug.
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Fix bzip main page
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Don't show comment message widget after clearing the comment view
  * libzip: use ZIP_FL_ENC_RAW for comments
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * clizip: fix list after adding files to encrypted archive
  * Stop ignoring compression options when dropping files (kde#396579)
  * Make CI happy (I hope:))
  * More strict compile flags
  * cliinterface: restore old working directory after extraction (kde#395939)
  * libarchive: restore old working directory after extraction
  * Add checks for expected working dir in the extraction tests
  * cliinterface: make m_operationMode protected
  * Revert "cliinterface: simplify cleanUpExtracting() usage"
  * libarchive: cleanup blank lines
  * libarchive: rename counter variables
  * libarchive: move variables closer to usage
  * cliinterface: simplify cleanUpExtracting() usage
  * Do not duplicate work of KAboutData::setupCommandLine()
  * flatpak: enable graphics acceleration
  * flatpak: drop QT_QPA_PLATFORM=flatpak
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * libzip: fix extraction of folders without zip entry (kde#394542)
* Fri Jun 29 2018 stefan.bruens@rwth-aachen.de
- Fix broken Recommends: p7zip-full, p7zip-full is only available on
  TW and contains the executables from the former p7zip package.
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Thu May 17 2018 kstreitova@suse.com
- Switch from "Recommends: p7zip" to "Recommends: p7zip-full" as
  Ark needs 7z executable that is now packaged in the p7zip-full
  package [bsc#899627]
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * libzipplugin: Add missing <memory> header
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Drop custom mimetypes
  * Enable targets generation in the bin subfolder of the build dir
  * Remove unnecessary moc includes
  * Don't override Job signals
  * LoadJob: check result in onFinished()
  * Rework kill logic (kde#389290)
  * libzip: implement killing TestJob
  * Stop emitting result() after doKill()
  * Add apidox to cancelled() signal
  * Fix apidox copy-paste bug
  * Fix valgrind uninitialised warnings
  * Fix mismatched new[] / delete[] valgrind warning
  * Drop dead code
  * Add apidox for waitForFinishedSignal()
  * Remove obsolete reviewboardrc file
  * Update apidox of extractFiles()
  * Add apidox for ReadWriteArchiveInterface::addFiles()
  * Fix threading issue
  * Fix stale comment
* Fri Mar 30 2018 wbauer@tmo.at
- Drop 0001-Swap-priorities-around-between-unar-and-unrar.patch
  again, unar's "unrar" wrapper has been split out and doesn't
  replace unrar anymore.
  There are good reasons not to prefer unar over unrar, it
  currently only supports a subset of RAR archives, and this also
  breaks creating of RAR archives with Ark if unar is installed.
  People who do want to install the new unrar_wrapper instead of
  the real unrar can still disable the rar plugin in Ark's settings
  to be able to open RAR archives with unar.
* Wed Mar 14 2018 lbeltrame@kde.org
- Add downstream patch 0001-Swap-priorities-around-between-unar-and-unrar.patch
  * Ensure unar is preferred over the unrar executable when only
    a wrapper is installed (boo#1083834)
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Add expected failures for timestamp tests
  * Fix build with Qt 5.11
  * Mark canceled extractions as killed jobs (kde#382601)
  * Stop crashing when all read-write plugins are disabled (kde#390690)
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * CreateDialog: remove trailing whitespace after last separator
  * libarchive: check isInterruptionRequested() in copyData()
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Set transient parent to extraction dialog
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * ExtractJob: set destination URL in the job description (kde#385043)
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * QDateTime::toSecsSinceEpoch() -> toMSecsSinceEpoch()
  * libzip: Preserve modtime when extracting (kde#380225)
  * Improve layout of internal previewer (kde#385710)
  * Increase max size of archive volumes (kde#384869)
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * part: update window title whenever the URL changes
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
- Drop 0001-Make-ArkViewer-a-KPart-mainwindow.patch (merged upstream)
* Mon Jul 17 2017 lnussel@suse.de
- unrar is non-free. Avoid installing it automatically.
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Prevent opening setting dialog twice
  * Remove stray $ from mime type list of the libzip plugin
- Drop upstreamed patches:
  * 0001-Remove-stray-from-mime-type-list-of-the-libzip-plugi.patch
* Sat Jun 10 2017 fabian@ritter-vogt.de
- Add patch to remove stray $ from supported MimeType list:
  * 0001-Remove-stray-from-mime-type-list-of-the-libzip-plugi.patch
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Don't crash when dropping twice invalid URLs on empty archive view
  * part: update actions when settings change
  * Respect file size limit when double cliclking
  * Fix crash when renaming top-level entries (kde#379802)
* Sun Jun  4 2017 fabian@ritter-vogt.de
- Add upstream commit from master to improve previewer (kde#380439):
  * 0001-Make-ArkViewer-a-KPart-mainwindow.patch
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Don't repeat work of KAboutData::setupCommandLine()
  * Call KAboutData::setApplicationData() earlier, in common place
  * Call kdoctools_install in addition to ki18n_install
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * cliunarchiver: Emit encryption method
  * Fix extraction of encrypted entries with the unar plugin
* Sat Apr 15 2017 fabian@ritter-vogt.de
- Only require libzip >= 1.2.0 on >= TW
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Mon Mar 27 2017 wbauer@tmo.at
- Add lower-libarchive-minimum-version.patch, this reverts the bump
  of the minimum libarchive version to 3.2.0 to make it build on
  Leap 42 (with libarchive 3.1.2)
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Fix archivemodel columns with singlefile archives (kde#376225)
  * Fix cross-thread object creation
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
- Drop 0001-Stop-running-executables-when-opening-urls.patch,
  merged upstream
* Fri Jan  6 2017 fabian@ritter-vogt.de
- Add patch to avoid running executable scripts when clicking on them:
  * 0001-Stop-running-executables-when-opening-urls.patch
    (kde#374572, boo#1018648)
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Thu Oct 13 2016 lbeltrame@kde.org
- Drop all patches, merged upstream:
  * 0001-SVN_SILENT-made-messages-after-extraction.patch
  * 0002-Add-support-for-application-vnd.rar-fixes-opening-RA.patch
  * 0003-Stop-crashing-when-dropping-on-empty-ArchiveView.patch
  * 0004-Show-extraction-dialog-only-after-archive-has-been-l.patch
  * 0005-SVN_SILENT-made-messages-after-extraction.patch
  * 0006-Accept-drop-events-when-creating-a-new-archive.patch
  * 0007-SVN_SILENT-made-messages-after-extraction.patch
  * 0008-Fix-potential-crash-when-aborting-a-ListJob.patch
  * 0009-Improve-focus-handling-of-internal-previewer.patch
  * 0010-SVN_SILENT-made-messages-.desktop-file-always-resolv.patch
  * 0011-Fix-drag-and-drop-with-RPM-archives.patch
  * 0012-Add-test-cases-for-RPM-and-AppImage.patch
  * 0013-Fix-drag-and-drop-extraction-of-entries-from-certain.patch
  * 0014-Fix-drag-and-drop-extraction-of-parentless-files.patch
* Wed Oct 12 2016 lbeltrame@kde.org
- Drop patches applied upstream
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
- https://www.kde.org/announcements/announce-applications-16.08.2.php
* Sat Oct  1 2016 fabian@ritter-vogt.de
- Replace mimeinfo17.patch by patches until git master:
  * 0001-SVN_SILENT-made-messages-after-extraction.patch
  * 0002-Add-support-for-application-vnd.rar-fixes-opening-RA.patch
  * 0003-Stop-crashing-when-dropping-on-empty-ArchiveView.patch
  * 0004-Show-extraction-dialog-only-after-archive-has-been-l.patch
  * 0005-SVN_SILENT-made-messages-after-extraction.patch
  * 0006-Accept-drop-events-when-creating-a-new-archive.patch
  * 0007-SVN_SILENT-made-messages-after-extraction.patch
  * 0008-Fix-potential-crash-when-aborting-a-ListJob.patch
  * 0009-Improve-focus-handling-of-internal-previewer.patch
  * 0010-SVN_SILENT-made-messages-.desktop-file-always-resolv.patch
  * 0011-Fix-drag-and-drop-with-RPM-archives.patch
  * 0012-Add-test-cases-for-RPM-and-AppImage.patch
  * 0013-Fix-drag-and-drop-extraction-of-entries-from-certain.patch
  * 0014-Fix-drag-and-drop-extraction-of-parentless-files.patch
- kde#369535, kde#369390, kde#369401, kde#369283, kde#368807, kde#368786, kde#367549
* Tue Sep 20 2016 fabian@ritter-vogt.de
- Add mimeinfo17.patch to fix opening .rar files with shared-mime-info 1.7
  * kde#368786
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
- Drop upstream patch
  * Fix-ark-cannout-open-rar-file-with-space-in-archive-file-path.patch
  * Fallback-to-read-only-mode-if-there-are-no-read-write-executables.patch
* Wed Dec 23 2015 wbauer@tmo.at
- Add Fallback-to-read-only-mode-if-there-are-no-read-write-executables.patch:
  fixes opening archives when the executable to create a new
  archive (e.g. rar or zip) is not installed (boo#959996, kde#357057)
* Tue Dec 22 2015 wbauer@tmo.at
- Add Fix-ark-cannout-open-rar-file-with-space-in-archive-file-path.patch:
  fixes opening rar files with a space in the file path (boo#959996)
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Fri Apr  4 2014 tittiatcoke@gmail.com
- Add recommends for additional compression programs based
  on bnc#872010
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Thu Mar 13 2014 hrvoje.senjan@gmail.com
- Minor spec cleanup
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
- Dropped patches due to upstream inclusion:
  ark-unrar5.diff
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Tue Aug 27 2013 hrvoje.senjan@gmail.com
- Added ark-unrar5.diff which adds support for unrar5 (kde#319303)
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Wed Jul 24 2013 hrvoje.senjan@gmail.com
- BuildRequire only libkde4-devel, instead of kdebase4-workspace-devel
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sun Nov 25 2012 tittiatcoke@gmail.com
- Drop patch 4_7_branch.diff as it is not used at all
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
  * Make it possible to disable the internal previewer
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Wed Aug  8 2012 mlin@suse.com
- fix files list
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Mon Jan 30 2012 saschpe@suse.de
- Ran spec-cleaner
- Removed outdated dependencies left from package split
- Packaged COPYING
- Adhere to shared library policy, split out libkerfuffle and a
  devel package
* Thu Jan 19 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan  3 2012 dmueller@suse.de
- update to 4.7.97
* Mon Jan  2 2012 dmueller@suse.de
- update to 4.7.96
* Tue Dec 20 2011 dmueller@suse.de
- update to 4.7.95
* Sat Dec  3 2011 dmueller@suse.de
- update to 4.7.90
* Thu Nov 17 2011 dmueller@suse.de
- update to 4.7.80
* Fri Nov  4 2011 dmueller@suse.de
- update to 4.7.46
* Thu Oct 20 2011 dmueller@suse.de
- update to 4.7.45
* Tue Oct 11 2011 dmueller@suse.de
- update to 4.7.44
* Mon Sep 26 2011 dmueller@suse.de
- update to 4.7.43
* Tue Aug 23 2011 tittiatcoke@gmail.com
- update to 4.7,42 (split off from kdeutils)
* Mon Aug 22 2011 dmueller@suse.de
- update to 4.7.41
* Sat Jul  9 2011 dmueller@suse.de
- update to 4.6.95
* Tue Jun 28 2011 dmueller@suse.de
- update to 4.6.90
* Fri May 20 2011 dmueller@suse.de
- update to 4.6.80
* Fri May 20 2011 dmueller@suse.de
- update to 4.6.79_20110520
* Sun May  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110508
* Mon May  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110502
* Sat Apr 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110423
* Wed Apr 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110420
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110418
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sun Apr  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110403
* Fri Apr  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110401
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110331
* Wed Mar 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110330
* Tue Mar 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110329
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Thu Mar 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110324
* Wed Mar 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110323
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Sat Mar 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110319
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110318
* Thu Mar 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110317
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110316
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Mon Mar 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110314
* Sun Mar 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110313
* Sat Mar 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110312
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110309
* Tue Mar  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110308
* Mon Mar  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110307
* Sun Mar  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110306
* Sat Mar  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110305
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110302
* Tue Mar  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110301
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sat Feb 26 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110226
* Fri Feb 25 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110225
* Thu Feb 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110224
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Sun Feb 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110220
* Sat Feb 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110219
* Fri Feb 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110218
* Thu Feb 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110215
* Mon Feb 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110214
* Sun Feb 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110213
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Thu Feb 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110210
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Mon Feb  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110207
* Sun Feb  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110206
* Sat Feb  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110205
* Fri Feb  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110204
* Thu Feb  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110203
* Wed Feb  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110202
* Tue Feb  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110201
* Mon Jan 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110131
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Fri Jan  7 2011 dmueller@suse.de
- update to 4.6.41_20110106
* Sun Dec 19 2010 tittiatcoke@gmail.com
- Update to 4.5.86svn1207757
* Fri Dec 10 2010 dmueller@suse.de
- update to 4.5.86svn1205247
* Wed Dec  1 2010 dmueller@suse.de
- update to 4.5.82svn1202688
* Mon Nov 29 2010 tittiatcoke@gmail.com
- Update to 4.5.81svn1202101
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Wed May 19 2010 llunak@novell.com
- printer-applet requires system-config-printer to run (bnc#551958)
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Fri Jan  8 2010 llunak@novell.com
- kdessh is no longer part of kdeutils
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Fri Nov 20 2009 beineri@opensuse.org
- updated patch to apply with fuzz=0
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: okteta, kgpg, kwallet, kdelirc, ark fixes
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Tue Aug 18 2009 beineri@opensuse.org
- fix irkick menu entry icon
* Sun Aug 16 2009 beineri@opensuse.org
- move superkaramba menu entry to System/Desktop Applet/
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Thu Jul  9 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Wed Feb 18 2009 dmueller@suse.de
- update branch diff
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Wed Jan 14 2009 dmueller@suse.de
- update to 4.1.96
* Fri Jan  9 2009 dmueller@suse.de
- update to KDE 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Mon Oct 20 2008 stbinner@suse.de
- fix build on s390/s390x
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Tue Aug 19 2008 stbinner@suse.de
- branch diff update (many ark bug fixes)
* Thu Jul 31 2008 dmueller@suse.de
- branch diff update
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Fri Jul 18 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Fri Jul  4 2008 dmueller@suse.de
- update to 4.0.85
* Tue Jul  1 2008 stbinner@suse.de
- fix build
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Wed Jun  4 2008 dmueller@suse.de
- Fix build
* Tue Jun  3 2008 wstephenson@suse.de
- Fix handling of numbers in some locales (bnc#396482)
* Tue May 27 2008 stbinner@suse.de
- fix menu entry for sweeper (bnc#394348)
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Fri Apr 25 2008 dmueller@suse.de
- fix filelist
* Mon Apr  7 2008 dmueller@suse.de
- build ark against libzip
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Tue Mar 11 2008 dmueller@suse.de
- 4_0_BRANCH.diff update
  * various bugfixes, translation update
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Fri Feb 15 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Sun Feb  3 2008 stbinner@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
* Sat Jan  5 2008 dmueller@suse.de
- update to 4.0
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.97.0
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Wed Oct 31 2007 dmueller@suse.de
- fix free() call
* Fri Oct 26 2007 dmueller@suse.de
- update to KDE 4.0 beta4
* Thu Oct 18 2007 dmueller@suse.de
- update to 3.94.1
* Thu Oct 11 2007 dmueller@suse.de
- update to KDE 4.0 Beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720587
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712063
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703919
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700769
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
* Sun Jul 29 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Wed Jul 18 2007 dmueller@suse.de
- remove xmms-devel
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685971
* Wed Jun 27 2007 stbinner@suse.de
- fix build in beta
* Tue Jun 26 2007 dmueller@suse.de
- fix file conflicts
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679151
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Mon Jun  4 2007 stbinner@suse.de
- fix build
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Mon May 28 2007 dmueller@suse.de
- update to 3.90.1.svn668119
* Sat May 12 2007 schwab@suse.de
- Fix dependencies.
* Sat May 12 2007 stbinner@suse.de
- libkdeinit -> libkdeinit4
* Fri May 11 2007 stbinner@suse.de
- initial package in abuild
